ScaleContext

Struct ScaleContext 

pub struct ScaleContext { /* private fields */ }
Available on crate feature scale only.
Context that manages caches and scratch buffers for scaling.

See the module level documentation for detail.

Implementations

Source

impl ScaleContext

pub fn new() -> Self

Creates a new scaling context.

pub fn with_max_entries(max_entries: usize) -> Self

Creates a new scaling context with the specified maximum number of cache entries.

pub fn builder<'a>( &'a mut self, font: impl Into<FontRef<'a>>, ) -> ScalerBuilder<'a>

Creates a new builder for constructing a scaler with this context and the specified font.

pub fn builder_with_id<'a>( &'a mut self, font: impl Into<FontRef<'a>>, id: [u64; 2], ) -> ScalerBuilder<'a>

Creates a new builder for constructing a scaler with this context, specified font and a custom unique identifier.