Struct swash::WritingSystem[][src]

pub struct WritingSystem<'a> { /* fields omitted */ }

Script, language and associated typographic features available in a font.

Implementations

impl<'a> WritingSystem<'a>[src]

pub fn script_tag(&self) -> Tag[src]

Returns the OpenType script tag for the writing system.

pub fn language_tag(&self) -> Tag[src]

Returns the OpenType language tag for the writing system.

pub fn script(&self) -> Option<Script>[src]

Returns the script for the writing system.

pub fn language(&self) -> Option<Language>[src]

Returns the language for the writing system.

pub fn features(&self) -> Features<'a>

Notable traits for Features<'a>

impl<'a> Iterator for Features<'a> type Item = Feature;
[src]

Returns an iterator over the features provided by the writing system.